# pymycqu

这个库对重庆大学 <https://my.cqu.edu.cn> 和统一身份认证的部分 web api 进行了封装，同时整理了相关数据模型。

Work in progress... 欢迎反馈和补充

感谢 <https://github.com/CQULHW/CQUQueryGrade> 项目提供了 <https://my.cqu.edu.cn> 的登陆方式。

## 安装

```bash
pip install mycqu
```

## 例子及文档

见 <https://pymycqu.hagb.name>.

## 许可

AGPL 3.0
